@@ -1,4 +1,4 @@
-// Copyright (c) 2010-2024, Lawrence Livermore National Security, LLC. Produced
+// Copyright (c) 2010-2025, Lawrence Livermore National Security, LLC. Produced
 // at the Lawrence Livermore National Laboratory. All Rights reserved. See files
 // LICENSE and NOTICE for details. LLNL-CODE-806117.
 //
@@ -44,7 +44,7 @@ struct TMOP
       fec(p, dim),
       fes(&mesh, &fec, dim),
       R(fes.GetElementRestriction(ElementDofOrdering::LEXICOGRAPHIC)),
-      ir(&IntRules.Get(fes.GetFE(0)->GetGeomType(), q)),
+      ir(&IntRules.Get(mesh.GetTypicalElementGeometry(), q)),
       nlfi(&metric, &target_c),
       dofs(fes.GetVSize()),
       x(&fes),
@@ -125,11 +125,11 @@ struct Kernel: public bm::Fixture
    ~Kernel() { assert(ker == nullptr); }
 
    using bm::Fixture::SetUp;
-   void SetUp(const bm::State& state) BENCHMARK_OVERRIDE
+   void SetUp(const bm::State& state) override
    { ker.reset(new TMOP(state.range(1), state.range(0))); }
 
    using bm::Fixture::TearDown;
-   void TearDown(const bm::State &) BENCHMARK_OVERRIDE { ker.reset(); }
+   void TearDown(const bm::State &) override { ker.reset(); }
 };
 
 /**
@@ -176,10 +176,11 @@ int main(int argc, char *argv[])
 
    // Device setup, cpu by default
    std::string device_config = "cpu";
-   if (bmi::global_context != nullptr)
+   auto global_context = bmi::GetGlobalContext();
+   if (bmi::GetGlobalContext() != nullptr)
    {
-      const auto device = bmi::global_context->find("device");
-      if (device != bmi::global_context->end())
+      const auto device = global_context->find("device");
+      if (device != global_context->end())
       {
          mfem::out << device->first << " : " << device->second << std::endl;
          device_config = device->second;
