@@ -94,7 +94,7 @@ void TestCalcDivShape(FiniteElement* fe, ElementTransformation * T, int res)
          if (fe->GetGeomType() == Geometry::PYRAMID &&
              (ip.z >= 1.0 || ip.y > 1.0 - ip.z || ip.x > 1.0 - ip.z)) { continue; }
 
-         CAPTURE(ip.x, ip.y, ip.z);
+         CAPTURE(ip.x, ip.y, dim == 3 ? ip.z : 0_r);
 
          fe->CalcDivShape(ip, weights);
 
@@ -215,7 +215,7 @@ void TestFDCalcDivShape(FiniteElement* fe, ElementTransformation * T, int order)
       IntegrationPoint pt = ir->IntPoint(i);
       fe->CalcDivShape(pt, dshape);
 
-      CAPTURE(pt.x, pt.y, pt.z);
+      CAPTURE(pt.x, pt.y, dim == 3 ? pt.z : 0_r);
 
       fdshape = 0.0;
       for (int d=0; d<dim; d++)
