@@ -1,4 +1,4 @@
-// Copyright (c) 2010-2024, Lawrence Livermore National Security, LLC. Produced
+// Copyright (c) 2010-2025, Lawrence Livermore National Security, LLC. Produced
 // at the Lawrence Livermore National Laboratory. All Rights reserved. See files
 // LICENSE and NOTICE for details. LLNL-CODE-806117.
 //
@@ -41,6 +41,7 @@ TEST_CASE("Quadrature Function Coefficients",
    {
       int nelems = quadf_coeff.Size() / quadf_coeff.GetVDim() / ir.GetNPoints();
       int vdim = ir.GetNPoints();
+      geom_facts->X.HostRead();
 
       for (int i = 0; i < nelems; i++)
       {
@@ -154,7 +155,7 @@ TEST_CASE("Quadrature Function Coefficients",
    }
 }
 
-TEST_CASE("Quadrature Function Integration", "[QuadratureFunction][CUDA]")
+TEST_CASE("Quadrature Function Integration", "[QuadratureFunction][GPU]")
 {
    auto fname = GENERATE(
                    "../../data/star.mesh",
@@ -299,3 +300,64 @@ TEST_CASE("Face Quadrature Function Coefficients", "[Coefficient]")
       }
    }
 }
+
+TEST_CASE("QuadratureFunction::ProjectGridFunction",
+          "[Coefficient][QuadratureFunction]")
+{
+   const int order = GENERATE(1, 2);
+   const auto mesh_fname = GENERATE(
+                              "../../data/star.mesh",
+                              "../../data/star-mixed.mesh",
+                              "../../data/fichera.mesh",
+                              "../../data/fichera-mixed.mesh",
+                              "../../data/inline-tri.mesh",
+                              "../../data/inline-tet.mesh",
+                              "../../data/inline-wedge.mesh",
+                              "../../data/inline-pyramid.mesh"
+                           );
+   CAPTURE(order, mesh_fname);
+
+   Mesh mesh(mesh_fname);
+   H1_FECollection fec(order, mesh.Dimension());
+   FiniteElementSpace fes(&mesh, &fec);
+
+   GridFunction gf(&fes);
+   gf.Randomize(1);
+   GridFunctionCoefficient coeff(&gf);
+
+   auto compare_qf_to_coeff = [](QuadratureFunction &qf, Coefficient &coeff)
+   {
+      auto &qs = *qf.GetSpace();
+      for (int i = 0; i < qs.GetNE(); ++i)
+      {
+         const IntegrationRule &ir = qs.GetIntRule(i);
+         ElementTransformation &T = *qs.GetTransformation(i);
+         Vector values;
+         qf.GetValues(i, values);
+         for (int iq = 0; iq < ir.Size(); ++iq)
+         {
+            const int iq_p = qs.GetPermutedIndex(i, iq);
+            const IntegrationPoint &ip = ir[iq];
+            REQUIRE(coeff.Eval(T, ip) == MFEM_Approx(values[iq_p]));
+         }
+      }
+   };
+
+   SECTION("QuadratureSpace")
+   {
+      QuadratureSpace qs(&mesh, order + 1);
+      QuadratureFunction qf(qs);
+      coeff.Project(qf);
+      compare_qf_to_coeff(qf, coeff);
+   }
+
+   SECTION("FaceQuadratureSpace")
+   {
+      const auto ftype = GENERATE(FaceType::Interior, FaceType::Boundary);
+      CAPTURE(ftype);
+      FaceQuadratureSpace qs(mesh, order + 1, ftype);
+      QuadratureFunction qf(qs);
+      coeff.Project(qf);
+      compare_qf_to_coeff(qf, coeff);
+   }
+}
