@@ -1,4 +1,4 @@
-// Copyright (c) 2010-2024, Lawrence Livermore National Security, LLC. Produced
+// Copyright (c) 2010-2025, Lawrence Livermore National Security, LLC. Produced
 // at the Lawrence Livermore National Laboratory. All Rights reserved. See files
 // LICENSE and NOTICE for details. LLNL-CODE-806117.
 //
@@ -18,8 +18,8 @@ class IdentitySolver : public Solver
 {
 public:
    IdentitySolver(int n) : Solver(n) { }
-   void Mult(const Vector& x, Vector& y) const { y = x; }
-   void SetOperator(const Operator& op) { }
+   void Mult(const Vector& x, Vector& y) const override { y = x; }
+   void SetOperator(const Operator& op) override { }
 };
 
 class SimpleSaddle
